@@ -169,6 +169,18 @@ class CommandTestCase(unittest.TestCase):
             default=lambda: None,
             show_default='Something computed at runtime',
         )
+        @click.option(
+            '--group',
+            default=[('foo', 'bar')],
+            nargs=2,
+            type=click.Tuple([str, str]),
+            multiple=True,
+            show_default=True,
+        )
+        @click.option(
+            '--only-show-default',
+            show_default="Some default computed at runtime!",
+        )
         def foobar(bar):
             """A sample command."""
             pass
@@ -195,6 +207,14 @@ class CommandTestCase(unittest.TestCase):
         .. option:: --param <param>
 
             :default: Something computed at runtime
+
+        .. option:: --group <group>
+
+            :default: ('foo', 'bar')
+
+        .. option:: --only-show-default <only_show_default>
+
+            :default: Some default computed at runtime!
         """
             ).lstrip(),
             '\n'.join(output),
@@ -325,6 +345,52 @@ class CommandTestCase(unittest.TestCase):
             '\n'.join(output),
         )
 
+    def test_no_line_wrapping_epilog(self):
+        r"""Validate behavior of the \b character in an epilog."""
+
+        @click.command(
+            epilog="""
+An epilog containing pre-wrapped text.
+
+\b
+This is
+a paragraph
+without rewrapping.
+
+And this is a paragraph
+that will be rewrapped again.
+"""
+        )
+        def foobar():
+            """A sample command."""
+
+        ctx = click.Context(foobar, info_name='foobar')
+        output = list(ext._format_command(ctx, nested='short'))
+
+        self.assertEqual(
+            textwrap.dedent(
+                """
+        A sample command.
+
+        .. program:: foobar
+        .. code-block:: shell
+
+            foobar [OPTIONS]
+
+
+        An epilog containing pre-wrapped text.
+
+        | This is
+        | a paragraph
+        | without rewrapping.
+
+        And this is a paragraph
+        that will be rewrapped again.
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
 
 class GroupTestCase(unittest.TestCase):
     """Validate basic ``click.Group`` instances."""
